@@ -7,25 +7,33 @@ use Cwd;
 use base qw(Module::Install::Base);
 use vars qw($VERSION);
 
-$VERSION = '0.06';
+$VERSION = '0.14';
 
 sub githubmeta {
   my $self = shift;
   return unless $Module::Install::AUTHOR;
   return unless _under_git();
+  my $remote = shift || 'origin';
   return unless $self->can_run('git');
-  return unless my ($git_url) = `git remote show origin` =~ /URL: (.*)$/m;
+  return unless my ($git_url) = `git remote show -n $remote` =~ /URL: (.*)$/m;
   return unless $git_url =~ /github\.com/; # Not a Github repository
   my $http_url = $git_url;
   $git_url =~ s![\w\-]+\@([^:]+):!git://$1/!;
-  $http_url =~ s![\w\-]+\@([^:]+):!http://$1/!;
+  $http_url =~ s![\w\-]+\@([^:]+):!https://$1/!;
   $http_url =~ s!\.git$!/tree!;
-  $self->repository( $git_url );
+  $self->repository(
+      {
+          type => 'git',
+          url  => $git_url,
+          web  => $http_url,
+      },
+  );
   $self->homepage( $http_url ) unless $self->homepage();
   return 1;
 }
 
 sub _under_git {
+  return 1 if -e '.git';
   my $cwd = getcwd;
   my $last = $cwd;
   my $found = 0;
@@ -46,4 +54,4 @@ sub _under_git {
 'Github';
 __END__
 
-#line 107
+#line 115
